@@ -3,9 +3,8 @@
 @author:XuMing(xuming624@qq.com)
 @description: 
 """
+__version__ = '1.0.7'
 
-from parrots.pinyin2hanzi import Pinyin2Hanzi
+from parrots import utils
 from parrots.asr import SpeechRecognition
-from parrots.tts import TextToSpeech
-
-__version__ = '0.1.7'
+from parrots.pinyin2hanzi import Pinyin2Hanzi
